The ``jicbioimage`` Python package
==================================

.. image:: https://badge.fury.io/py/jicbioimage.svg
   :target: http://badge.fury.io/py/jicbioimage
   :alt: PyPi package

.. image::
   https://readthedocs.org/projects/jicbioimage/badge/?version=latest
   :target: https://readthedocs.org/projects/jicbioimage?badge=latest
   :alt: Documentation Status

The ``jicbioimage`` Python package makes it easy to explore microscopy
data in a programmatic fashion. Exploring images via coding means that the
exploratory work becomes recorded and reproducible.  Furthermore, it makes it
easier to convert the exploratory work into (semi) automated analysis work
flows.

- Documentation: http://jicbioimage.readthedocs.org
- GitHub: https://github.com/JIC-CSB/jicbioimage
- PyPI: https://pypi.python.org/pypi/jicbioimage
- Free software: MIT License

Features
--------

- Built in functionality for working with microscopy data
- Automatic generation of audit trails
- IPython integration
- Cross-platform: Linux, Mac and Windows are all supported
- Works with Python 2.7, 3.3 and 3.4

Related packages
----------------

``jicbioimage.core``
^^^^^^^^^^^^^^^^^^^^

- Documentation: http://jicbioimagecore.readthedocs.org
- GitHub: https://github.com/JIC-CSB/jicbioimage.core

``jicbioimage.transform``
^^^^^^^^^^^^^^^^^^^^^^^^^

- Documentation: http://jicbioimagetransform.readthedocs.org
- GitHub: https://github.com/JIC-CSB/jicbioimage.transform
